@@ -8,11 +8,17 @@ ulimit -H -l unlimited 2>/dev/null || {
 	exit 77
 }
 
+# ufw currently broken without /sbin/iptables
+if ! ufw status; then
+	test -e /sbin/iptables  || ln -s /usr/sbin/iptables /sbin/iptables
+	test -e /sbin/ip6tables || ln -s /usr/sbin/ip6tables /sbin/ip6tables
+fi
+
 service corosync stop
 
-crm cluster init --yes --name=autopkgtest --unicast
+crm cluster init --yes --name=autopkgtest
 
-crm cluster geo-init --yes --clusters=autopkgtest=127.2.2.2 --tickets=ticket1
+crm cluster geo_init --yes --clusters=autopkgtest=127.2.2.2 --tickets=ticket1
 crm resource start g-booth
 sleep 5
 
