@@ -3,7 +3,7 @@
 set -ex
 
 export LC_ALL=C
-PKG=vim
+PKG=fence-virt
 
 dpkg --purge $PKG
 
@@ -16,7 +16,7 @@ dpkg --purge $PKG
 dpkg --status $PKG
 
 # upgrade
-/usr/share/crmsh/utils/crm_pkg.py -n $PKG -s latest | grep false
+/usr/share/crmsh/utils/crm_pkg.py -n $PKG -s latest | grep False
 
 # purge
 /usr/share/crmsh/utils/crm_pkg.py -n $PKG -s removed | egrep 'Removing|Purging'
